# testthat sources files beginning with helper- before running unit tests.
# This helper file contains data for each of the unit tests so that it is not
# repeated across test files.

# TODO Update matrices with 1 and 2 cell islands when the tests are adjusted for it
# TODO Rename matrices (at least abs)

res <- matrix(c(1,  1,  2,  2,  3,  3,  2,  2,  1,  1,
                1,  2,  2,  3, 10, 10,  3,  2,  2,  1,
                1,  2,  2,  3, 10, 10,  3,  2,  2,  1,
                1,  1,  1, NA, NA, NA, NA,  1,  1,  1,
                1,  1,  1, NA, NA, NA, NA,  1,  1,  1,
                1,  1,  1, NA, NA, NA, NA,  1,  1,  1,
                1,  1,  1, NA, NA, NA, NA,  1,  1,  1,
                1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
                1,  1, 10, 10, 10, 10, 10, 10,  1,  1,
                1,  1,  1,  1,  1,  1,  1,  1,  1,  1),
              nrow = 10)

abs <- matrix(c(1,  2,  1,  1,  1,  1,  1,  1,  1,  4,
                1,  1,  1,  2,  2,  1,  1,  0,  1,  5,
                1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
                1,  1,  1, NA, NA, NA, NA,  1,  1,  1,
                1,  5,  1, NA, NA, NA, NA,  0,  0,  1,
                1,  1,  1, NA, NA, NA, NA,  1,  0,  1,
                1,  1,  1, NA, NA, NA, NA,  1,  0,  1,
                1,  1,  1,  2,  1,  1,  1,  7,  7,  1,
                1,  1,  1,  1,  1,  1,  1,  7,  7,  1,
                3,  1,  1,  1,  1,  1,  1,  1,  1,  1),
              nrow = 10)
abs <- abs/1000

fid <- matrix(c(10, 10, 10, 10, 10, 10, 10, 10, 10, 10,
                10, 10, 10, 10,  1,  1, 10, 10, 10, 10,
                10, 10, 10, 10,  1,  1, 10, 10, 10, 10,
                10, 10, 10, NA, NA, NA, NA, 10, 10, 10,
                10, 10, 10, NA, NA, NA, NA, 50, 50, 10,
                10, 10, 10, NA, NA, NA, NA, 50, 50, 10,
                10, 10, 10, NA, NA, NA, NA, 10, 10, 10,
                10, 10, 10, 10, 10, 10, 10, 10, 10, 10,
                10, 10, 10, 10, 10, 10, 10, 10, 10, 10,
                10, 10, 10, 10, 10, 10, 10, 10, 10, 10),
              nrow = 10)
fid <- fid/100

occ <- matrix(c(0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
                0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
                0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
                0,  0,  0, NA, NA, NA, NA,  0,  0,  0,
                0,  1,  1, NA, NA, NA, NA,  0,  0,  0,
                0,  1,  1, NA, NA, NA, NA,  0,  0,  0,
                0,  0,  0, NA, NA, NA, NA,  0,  0,  0,
                0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
                0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
                0,  0,  0,  0,  0,  0,  0,  0,  0,  0),
              nrow = 10)

row = 13
col = 23
time = 100
time_vec = c(3, 5, 7, 11, 13)
row_vec = c(7, 34, 5, 5)
col_vec = c(13, 13, 5, 19)

